@@ -14,7 +14,7 @@ import bciavm.pipelines
 import bciavm.preprocessing
 import bciavm.problem_types
 import bciavm.utils
-import bciavm.data
+# import bciavm.data
 import bciavm.core
 
 from bciavm.utils import print_info
