@@ -45,6 +45,7 @@ import mlflow
 from mlflow.tracking import MlflowClient
 from ..utils.gen_utils import fill_nulls
 import pkgutil
+from joblib import Parallel, delayed
 
 client = MlflowClient()
 
@@ -158,7 +159,6 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
         self.data = pd.DataFrame({})
         for ct in range(1, 4):
-            # d = io.BytesIO(pkgutil.get_data('bci_avm.data.dfPricesEpc_parquet', 'data' + str(ct) + '.parquet'))
             d = 'https://bciavm.s3.amazonaws.com/dfPricesEpc_parquet/data'+str(ct)+'.parquet'
             self.data = self.data.append(pd.read_parquet(d))
 
@@ -350,6 +350,11 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
     def _get_conf(self, model_input):
         self.l = [ ]
         self.model_input = model_input
+
+        # from joblib import parallel_backend
+        # with parallel_backend('dask', n_jobs=-1):
+        #     Parallel()(delayed(self._conf)(unit_index) for unit_index in model_input[ 'unit_index' ].values)
+
         model_input[ 'unit_index' ].apply(self._conf)
         dfx = pd.concat(self.l, ignore_index=True)
         dfx[ 'avm' ] = round(dfx[ 'avm' ].astype(float), 0)
